@@ -5,20 +5,21 @@ from abc import ABCMeta, abstractmethod
 class AbstractBuffer(metaclass=ABCMeta):
     """
     """
-    def __init__(self, settings):
+    def __init__(self):
         """
         """
         pass
 
     @abstractmethod    
-    def add(self, experience):
+    def add(self, list_experiences):
         """
         """
         pass
 
     @abstractmethod             
     def sample(self, num):
-        """
-        """
+        """ return: dict
+            batch_sample = {"data": [], "position": []}
+        """ 
         pass
 
